pub fn stream_profile<P, F>(file_path: P, _callback: F) -> Result<QualityReport>Expand description
Stream profiling with intelligent engine selection and progress logging
pub fn stream_profile<P, F>(file_path: P, _callback: F) -> Result<QualityReport>Stream profiling with intelligent engine selection and progress logging