pub enum MetricPack {
Schema,
Statistics,
Patterns,
Quality,
}Expand description
High-level categories of analysis that can be selectively enabled.
Variants
Schema
Column names, data types, null counts — always included.
Statistics
Numeric stats (min/max/mean/median/std_dev/quartiles), text lengths.
Patterns
Regex pattern detection (email, phone, UUID, etc.).
Quality
ISO 25012 quality dimensions (completeness, consistency, etc.).
Implementations
Sourceimpl MetricPack
impl MetricPack
Sourcepub fn all() -> Vec<MetricPack>
pub fn all() -> Vec<MetricPack>
All available metric packs.
Sourcepub fn include_statistics(packs: Option<&[MetricPack]>) -> bool
pub fn include_statistics(packs: Option<&[MetricPack]>) -> bool
Whether statistics should be computed given the selected packs.
Sourcepub fn include_patterns(packs: Option<&[MetricPack]>) -> bool
pub fn include_patterns(packs: Option<&[MetricPack]>) -> bool
Whether pattern detection should run given the selected packs.
Sourcepub fn include_quality(packs: Option<&[MetricPack]>) -> bool
pub fn include_quality(packs: Option<&[MetricPack]>) -> bool
Whether quality metrics should be computed given the selected packs.