pub struct FrequencyItem {
pub value: String,
pub count: usize,
pub percentage: f64,
}Expand description
A value and its frequency count within a column.
Fields
value: Stringcount: usizepercentage: f64Trait Implementations
Sourceimpl Clone for FrequencyItem
impl Clone for FrequencyItem
Sourcefn clone(&self) -> FrequencyItem
fn clone(&self) -> FrequencyItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrequencyItem
impl Debug for FrequencyItem
Sourceimpl<'de> Deserialize<'de> for FrequencyItem
impl<'de> Deserialize<'de> for FrequencyItem
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FrequencyItem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FrequencyItem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FrequencyItem
impl PartialEq for FrequencyItem
Sourcefn eq(&self, other: &FrequencyItem) -> bool
fn eq(&self, other: &FrequencyItem) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FrequencyItem
impl Serialize for FrequencyItem
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for FrequencyItem